class Events_Latest:
    def events():
        from ..Basic.Settings import Settings as st
        from ..Basic.Common_Function import Common_Function as co_f
        print("=" * st.SEPALATE_LEN)
        print("現在開催中のイベントはありません")
        print("=" * st.SEPALATE_LEN)
        return